#! /bin/bash

set -x

exec 2>&1 > upgrade.log

sudo apt-get full-upgrade -y

exit 0
